User Guide
==========

This section contains guides and documents about some aspects of PyHMMER, 
including the rationale behind the parallelization strategy implemented 
in `pyhmmer.hmmer`.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

    Installation <install>
    Publications <publications>
    Performance <performance>

.. toctree::
   :maxdepth: 1
   :caption: Resources

   Contribution Guide <contributing>
   Changelog <changes>
   Benchmarks <benchmarks>
   Copyright Notice <copyright>
